import typing

import java
import java.lang

class BooleanAction(ControlAction):
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, newState: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, newState: bool | java.jboolean | java.lang.Boolean, challengeValue: str | java.lang.String, /) -> None: ...
    def getActionType(self) -> int: ...
    def getNewState(self) -> bool: ...

class CommandAction(ControlAction):
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, challengeValue: str | java.lang.String, /) -> None: ...
    def getActionType(self) -> int: ...

class ControlAction(java.lang.Object):
    RESPONSE_CHALLENGE_ACK: typing.ClassVar[int] = ...
    RESPONSE_CHALLENGE_PASSPHRASE: typing.ClassVar[int] = ...
    RESPONSE_CHALLENGE_PIN: typing.ClassVar[int] = ...
    RESPONSE_FAIL: typing.ClassVar[int] = ...
    RESPONSE_OK: typing.ClassVar[int] = ...
    RESPONSE_UNKNOWN: typing.ClassVar[int] = ...
    TYPE_BOOLEAN: typing.ClassVar[int] = ...
    TYPE_COMMAND: typing.ClassVar[int] = ...
    TYPE_ERROR: typing.ClassVar[int] = ...
    TYPE_FLOAT: typing.ClassVar[int] = ...
    TYPE_MODE: typing.ClassVar[int] = ...
    def getActionType(self) -> int: ...
    def getChallengeValue(self) -> str | None: ...
    @staticmethod
    def getErrorAction() -> ControlAction: ...
    def getTemplateId(self) -> str: ...
    @staticmethod
    def isValidResponse(response: int | java.jint | java.lang.Integer, /) -> bool: ...

class FloatAction(ControlAction):
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, newValue: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, newValue: float | java.jfloat | java.lang.Float, challengeValue: str | java.lang.String, /) -> None: ...
    def getActionType(self) -> int: ...
    def getNewValue(self) -> float: ...

class ModeAction(ControlAction):
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, newMode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, templateId: str | java.lang.String, newMode: int | java.jint | java.lang.Integer, challengeValue: str | java.lang.String, /) -> None: ...
    def getActionType(self) -> int: ...
    def getNewMode(self) -> int: ...



import typing

import android.app
import android.content
import android.os
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class AbstractAccountAuthenticator(java.lang.Object):
    KEY_CUSTOM_TOKEN_EXPIRY: typing.ClassVar[str] = ...
    def __init__(self, context: android.content.Context, /) -> None: ...
    def addAccount(self, arg1: AccountAuthenticatorResponse, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: java.chaquopy.JavaArray[java.lang.String], arg5: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def addAccountFromCredentials(self, response: AccountAuthenticatorResponse, account: Account, accountCredentials: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def confirmCredentials(self, arg1: AccountAuthenticatorResponse, arg2: Account, arg3: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def editProperties(self, arg1: AccountAuthenticatorResponse, arg2: str | java.lang.String, /) -> android.os.Bundle: ...
    def finishSession(self, response: AccountAuthenticatorResponse, accountType: str | java.lang.String, sessionBundle: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def getAccountCredentialsForCloning(self, response: AccountAuthenticatorResponse, account: Account, /) -> android.os.Bundle | None: ...
    def getAccountRemovalAllowed(self, response: AccountAuthenticatorResponse, account: Account, /) -> android.os.Bundle | None: ...
    def getAuthToken(self, arg1: AccountAuthenticatorResponse, arg2: Account, arg3: str | java.lang.String, arg4: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def getAuthTokenLabel(self, arg1: str | java.lang.String, /) -> str | None: ...
    def getIBinder(self) -> android.os.IBinder: ...
    def hasFeatures(self, arg1: AccountAuthenticatorResponse, arg2: Account, arg3: java.chaquopy.JavaArray[java.lang.String], /) -> android.os.Bundle | None: ...
    def isCredentialsUpdateSuggested(self, response: AccountAuthenticatorResponse, account: Account, statusToken: str | java.lang.String, /) -> android.os.Bundle | None: ...
    def startAddAccountSession(self, response: AccountAuthenticatorResponse, accountType: str | java.lang.String, authTokenType: str | java.lang.String, requiredFeatures: java.chaquopy.JavaArray[java.lang.String], options: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def startUpdateCredentialsSession(self, response: AccountAuthenticatorResponse, account: Account, authTokenType: str | java.lang.String, options: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def updateCredentials(self, arg1: AccountAuthenticatorResponse, arg2: Account, arg3: str | java.lang.String, arg4: android.os.Bundle, /) -> android.os.Bundle | None: ...

class Account(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Account]] = ...
    name: str = ...
    type: str = ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, type: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AccountAuthenticatorActivity(android.app.Activity):
    def __init__(self) -> None: ...
    def finish(self) -> None: ...
    def onCreate(self, icicle: android.os.Bundle, /) -> None: ...
    def setAccountAuthenticatorResult(self, result: android.os.Bundle, /) -> None: ...

class AccountAuthenticatorResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AccountAuthenticatorResponse]] = ...
    def __init__(self, parcel: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def onError(self, errorCode: int | java.jint | java.lang.Integer, errorMessage: str | java.lang.String, /) -> None: ...
    def onRequestContinued(self) -> None: ...
    def onResult(self, result: android.os.Bundle, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AccountManager(java.lang.Object):
    ACTION_ACCOUNT_REMOVED: typing.ClassVar[str] = ...
    ACTION_AUTHENTICATOR_INTENT: typing.ClassVar[str] = ...
    AUTHENTICATOR_ATTRIBUTES_NAME: typing.ClassVar[str] = ...
    AUTHENTICATOR_META_DATA_NAME: typing.ClassVar[str] = ...
    ERROR_CODE_BAD_ARGUMENTS: typing.ClassVar[int] = ...
    ERROR_CODE_BAD_AUTHENTICATION: typing.ClassVar[int] = ...
    ERROR_CODE_BAD_REQUEST: typing.ClassVar[int] = ...
    ERROR_CODE_CANCELED: typing.ClassVar[int] = ...
    ERROR_CODE_INVALID_RESPONSE: typing.ClassVar[int] = ...
    ERROR_CODE_NETWORK_ERROR: typing.ClassVar[int] = ...
    ERROR_CODE_REMOTE_EXCEPTION: typing.ClassVar[int] = ...
    ERROR_CODE_UNSUPPORTED_OPERATION: typing.ClassVar[int] = ...
    KEY_ACCOUNTS: typing.ClassVar[str] = ...
    KEY_ACCOUNT_AUTHENTICATOR_RESPONSE: typing.ClassVar[str] = ...
    KEY_ACCOUNT_MANAGER_RESPONSE: typing.ClassVar[str] = ...
    KEY_ACCOUNT_NAME: typing.ClassVar[str] = ...
    KEY_ACCOUNT_SESSION_BUNDLE: typing.ClassVar[str] = ...
    KEY_ACCOUNT_STATUS_TOKEN: typing.ClassVar[str] = ...
    KEY_ACCOUNT_TYPE: typing.ClassVar[str] = ...
    KEY_ANDROID_PACKAGE_NAME: typing.ClassVar[str] = ...
    KEY_AUTHENTICATOR_TYPES: typing.ClassVar[str] = ...
    KEY_AUTHTOKEN: typing.ClassVar[str] = ...
    KEY_AUTH_FAILED_MESSAGE: typing.ClassVar[str] = ...
    KEY_AUTH_TOKEN_LABEL: typing.ClassVar[str] = ...
    KEY_BOOLEAN_RESULT: typing.ClassVar[str] = ...
    KEY_CALLER_PID: typing.ClassVar[str] = ...
    KEY_CALLER_UID: typing.ClassVar[str] = ...
    KEY_ERROR_CODE: typing.ClassVar[str] = ...
    KEY_ERROR_MESSAGE: typing.ClassVar[str] = ...
    KEY_INTENT: typing.ClassVar[str] = ...
    KEY_LAST_AUTHENTICATED_TIME: typing.ClassVar[str] = ...
    KEY_PASSWORD: typing.ClassVar[str] = ...
    KEY_USERDATA: typing.ClassVar[str] = ...
    LOGIN_ACCOUNTS_CHANGED_ACTION: typing.ClassVar[str] = ...
    PACKAGE_NAME_KEY_LEGACY_NOT_VISIBLE: typing.ClassVar[str] = ...
    PACKAGE_NAME_KEY_LEGACY_VISIBLE: typing.ClassVar[str] = ...
    VISIBILITY_NOT_VISIBLE: typing.ClassVar[int] = ...
    VISIBILITY_UNDEFINED: typing.ClassVar[int] = ...
    VISIBILITY_USER_MANAGED_NOT_VISIBLE: typing.ClassVar[int] = ...
    VISIBILITY_USER_MANAGED_VISIBLE: typing.ClassVar[int] = ...
    VISIBILITY_VISIBLE: typing.ClassVar[int] = ...
    def addAccount(self, accountType: str | java.lang.String, authTokenType: str | java.lang.String, requiredFeatures: java.chaquopy.JavaArray[java.lang.String], addAccountOptions: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    @typing.overload
    def addAccountExplicitly(self, account: Account, password: str | java.lang.String, userdata: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def addAccountExplicitly(self, account: Account, password: str | java.lang.String, extras: android.os.Bundle, visibility: java.util.Map[java.lang.String, java.lang.Integer], /) -> bool: ...
    @typing.overload
    def addOnAccountsUpdatedListener(self, listener: OnAccountsUpdateListener, handler: android.os.Handler, updateImmediately: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def addOnAccountsUpdatedListener(self, listener: OnAccountsUpdateListener, handler: android.os.Handler, updateImmediately: bool | java.jboolean | java.lang.Boolean, accountTypes: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def blockingGetAuthToken(self, account: Account, authTokenType: str | java.lang.String, notifyAuthFailure: bool | java.jboolean | java.lang.Boolean, /) -> str | None: ...
    def clearPassword(self, account: Account, /) -> None: ...
    def confirmCredentials(self, account: Account, options: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def editProperties(self, accountType: str | java.lang.String, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def finishSession(self, sessionBundle: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    @staticmethod
    def get(context: android.content.Context, /) -> AccountManager: ...
    def getAccountVisibility(self, account: Account, packageName: str | java.lang.String, /) -> int: ...
    def getAccounts(self) -> java.chaquopy.JavaArray[Account]: ...
    def getAccountsAndVisibilityForPackage(self, packageName: str | java.lang.String, accountType: str | java.lang.String, /) -> java.util.Map[Account, java.lang.Integer]: ...
    def getAccountsByType(self, type: str | java.lang.String, /) -> java.chaquopy.JavaArray[Account]: ...
    def getAccountsByTypeAndFeatures(self, type: str | java.lang.String, features: java.chaquopy.JavaArray[java.lang.String], callback: AccountManagerCallback[java.chaquopy.JavaArray[Account]], handler: android.os.Handler, /) -> AccountManagerFuture[java.chaquopy.JavaArray[Account]]: ...
    def getAccountsByTypeForPackage(self, type: str | java.lang.String, packageName: str | java.lang.String, /) -> java.chaquopy.JavaArray[Account]: ...
    @typing.overload
    def getAuthToken(self, account: Account, authTokenType: str | java.lang.String, notifyAuthFailure: bool | java.jboolean | java.lang.Boolean, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    @typing.overload
    def getAuthToken(self, account: Account, authTokenType: str | java.lang.String, options: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    @typing.overload
    def getAuthToken(self, account: Account, authTokenType: str | java.lang.String, options: android.os.Bundle, notifyAuthFailure: bool | java.jboolean | java.lang.Boolean, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def getAuthTokenByFeatures(self, accountType: str | java.lang.String, authTokenType: str | java.lang.String, features: java.chaquopy.JavaArray[java.lang.String], activity: android.app.Activity, addAccountOptions: android.os.Bundle, getAuthTokenOptions: android.os.Bundle, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def getAuthenticatorTypes(self) -> java.chaquopy.JavaArray[AuthenticatorDescription]: ...
    def getPackagesAndVisibilityForAccount(self, account: Account, /) -> java.util.Map[java.lang.String, java.lang.Integer]: ...
    def getPassword(self, account: Account, /) -> str | None: ...
    def getPreviousName(self, account: Account, /) -> str | None: ...
    def getUserData(self, account: Account, key: str | java.lang.String, /) -> str | None: ...
    def hasFeatures(self, account: Account, features: java.chaquopy.JavaArray[java.lang.String], callback: AccountManagerCallback[java.lang.Boolean], handler: android.os.Handler, /) -> AccountManagerFuture[java.lang.Boolean]: ...
    def invalidateAuthToken(self, accountType: str | java.lang.String, authToken: str | java.lang.String, /) -> None: ...
    def isCredentialsUpdateSuggested(self, account: Account, statusToken: str | java.lang.String, callback: AccountManagerCallback[java.lang.Boolean], handler: android.os.Handler, /) -> AccountManagerFuture[java.lang.Boolean]: ...
    @typing.overload
    @staticmethod
    def newChooseAccountIntent(selectedAccount: Account, allowableAccounts: java.util.List[Account], allowableAccountTypes: java.chaquopy.JavaArray[java.lang.String], descriptionOverrideText: str | java.lang.String, addAccountAuthTokenType: str | java.lang.String, addAccountRequiredFeatures: java.chaquopy.JavaArray[java.lang.String], addAccountOptions: android.os.Bundle, /) -> android.content.Intent: ...
    @typing.overload
    @staticmethod
    def newChooseAccountIntent(selectedAccount: Account, allowableAccounts: java.util.ArrayList[Account], allowableAccountTypes: java.chaquopy.JavaArray[java.lang.String], alwaysPromptForAccount: bool | java.jboolean | java.lang.Boolean, descriptionOverrideText: str | java.lang.String, addAccountAuthTokenType: str | java.lang.String, addAccountRequiredFeatures: java.chaquopy.JavaArray[java.lang.String], addAccountOptions: android.os.Bundle, /) -> android.content.Intent: ...
    def notifyAccountAuthenticated(self, account: Account, /) -> bool: ...
    def peekAuthToken(self, account: Account, authTokenType: str | java.lang.String, /) -> str | None: ...
    @typing.overload
    def removeAccount(self, account: Account, callback: AccountManagerCallback[java.lang.Boolean], handler: android.os.Handler, /) -> AccountManagerFuture[java.lang.Boolean]: ...
    @typing.overload
    def removeAccount(self, account: Account, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def removeAccountExplicitly(self, account: Account, /) -> bool: ...
    def removeOnAccountsUpdatedListener(self, listener: OnAccountsUpdateListener, /) -> None: ...
    def renameAccount(self, account: Account, newName: str | java.lang.String, callback: AccountManagerCallback[Account], handler: android.os.Handler, /) -> AccountManagerFuture[Account]: ...
    def setAccountVisibility(self, account: Account, packageName: str | java.lang.String, visibility: int | java.jint | java.lang.Integer, /) -> bool: ...
    def setAuthToken(self, account: Account, authTokenType: str | java.lang.String, authToken: str | java.lang.String, /) -> None: ...
    def setPassword(self, account: Account, password: str | java.lang.String, /) -> None: ...
    def setUserData(self, account: Account, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def startAddAccountSession(self, accountType: str | java.lang.String, authTokenType: str | java.lang.String, requiredFeatures: java.chaquopy.JavaArray[java.lang.String], options: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def startUpdateCredentialsSession(self, account: Account, authTokenType: str | java.lang.String, options: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...
    def updateCredentials(self, account: Account, authTokenType: str | java.lang.String, options: android.os.Bundle, activity: android.app.Activity, callback: AccountManagerCallback[android.os.Bundle], handler: android.os.Handler, /) -> AccountManagerFuture[android.os.Bundle]: ...

_AccountManagerCallback__V = typing.TypeVar('_AccountManagerCallback__V')  # <V>
class AccountManagerCallback(java.lang.Object, typing.Generic[_AccountManagerCallback__V]):
    def run(self, arg1: AccountManagerFuture[_AccountManagerCallback__V], /) -> None: ...

_AccountManagerFuture__V = typing.TypeVar('_AccountManagerFuture__V')  # <V>
class AccountManagerFuture(java.lang.Object, typing.Generic[_AccountManagerFuture__V]):
    def cancel(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    @typing.overload
    def getResult(self) -> _AccountManagerFuture__V: ...
    @typing.overload
    def getResult(self, arg1: int | java.jlong | java.lang.Long, arg2: java.util.concurrent.TimeUnit, /) -> _AccountManagerFuture__V: ...
    def isCancelled(self) -> bool: ...
    def isDone(self) -> bool: ...

class AccountsException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class AuthenticatorDescription(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AuthenticatorDescription]] = ...
    accountPreferencesId: int = ...
    customTokens: bool = ...
    iconId: int = ...
    labelId: int = ...
    packageName: str = ...
    smallIconId: int = ...
    type: str = ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, packageName: str | java.lang.String, labelId: int | java.jint | java.lang.Integer, iconId: int | java.jint | java.lang.Integer, smallIconId: int | java.jint | java.lang.Integer, prefId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, type: str | java.lang.String, packageName: str | java.lang.String, labelId: int | java.jint | java.lang.Integer, iconId: int | java.jint | java.lang.Integer, smallIconId: int | java.jint | java.lang.Integer, prefId: int | java.jint | java.lang.Integer, customTokens: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def newKey(type: str | java.lang.String, /) -> AuthenticatorDescription: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AuthenticatorException(AccountsException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class NetworkErrorException(AccountsException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class OnAccountsUpdateListener(java.lang.Object):
    def onAccountsUpdated(self, arg1: java.chaquopy.JavaArray[Account], /) -> None: ...

class OperationCanceledException(AccountsException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...



import typing

import java
import java.chaquopy
import java.lang
import java.util

class AcousticEchoCanceler(AudioEffect):
    @staticmethod
    def create(audioSession: int | java.jint | java.lang.Integer, /) -> AcousticEchoCanceler | None: ...
    @staticmethod
    def isAvailable() -> bool: ...

class AudioEffect(java.lang.Object):
    ACTION_CLOSE_AUDIO_EFFECT_CONTROL_SESSION: typing.ClassVar[str] = ...
    ACTION_DISPLAY_AUDIO_EFFECT_CONTROL_PANEL: typing.ClassVar[str] = ...
    ACTION_OPEN_AUDIO_EFFECT_CONTROL_SESSION: typing.ClassVar[str] = ...
    ALREADY_EXISTS: typing.ClassVar[int] = ...
    CONTENT_TYPE_GAME: typing.ClassVar[int] = ...
    CONTENT_TYPE_MOVIE: typing.ClassVar[int] = ...
    CONTENT_TYPE_MUSIC: typing.ClassVar[int] = ...
    CONTENT_TYPE_VOICE: typing.ClassVar[int] = ...
    EFFECT_AUXILIARY: typing.ClassVar[str] = ...
    EFFECT_INSERT: typing.ClassVar[str] = ...
    EFFECT_POST_PROCESSING: typing.ClassVar[str] = ...
    EFFECT_PRE_PROCESSING: typing.ClassVar[str] = ...
    EFFECT_TYPE_AEC: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_AGC: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_BASS_BOOST: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_DYNAMICS_PROCESSING: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_ENV_REVERB: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_EQUALIZER: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_HAPTIC_GENERATOR: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_LOUDNESS_ENHANCER: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_NS: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_PRESET_REVERB: typing.ClassVar[java.util.UUID] = ...
    EFFECT_TYPE_VIRTUALIZER: typing.ClassVar[java.util.UUID] = ...
    ERROR: typing.ClassVar[int] = ...
    ERROR_BAD_VALUE: typing.ClassVar[int] = ...
    ERROR_DEAD_OBJECT: typing.ClassVar[int] = ...
    ERROR_INVALID_OPERATION: typing.ClassVar[int] = ...
    ERROR_NO_INIT: typing.ClassVar[int] = ...
    ERROR_NO_MEMORY: typing.ClassVar[int] = ...
    EXTRA_AUDIO_SESSION: typing.ClassVar[str] = ...
    EXTRA_CONTENT_TYPE: typing.ClassVar[str] = ...
    EXTRA_PACKAGE_NAME: typing.ClassVar[str] = ...
    SUCCESS: typing.ClassVar[int] = ...
    def finalize(self) -> None: ...
    def getDescriptor(self) -> AudioEffect.Descriptor: ...
    def getEnabled(self) -> bool: ...
    def getId(self) -> int: ...
    def hasControl(self) -> bool: ...
    @staticmethod
    def queryEffects() -> java.chaquopy.JavaArray[AudioEffect.Descriptor]: ...
    def release(self) -> None: ...
    def setControlStatusListener(self, listener: AudioEffect.OnControlStatusChangeListener, /) -> None: ...
    def setEnableStatusListener(self, listener: AudioEffect.OnEnableStatusChangeListener, /) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> int: ...

    class OnEnableStatusChangeListener(java.lang.Object):
        def onEnableStatusChange(self, arg1: AudioEffect, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class OnControlStatusChangeListener(java.lang.Object):
        def onControlStatusChange(self, arg1: AudioEffect, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class Descriptor(java.lang.Object):
        connectMode: str = ...
        implementor: str = ...
        name: str = ...
        type: java.util.UUID = ...
        uuid: java.util.UUID = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, type: str | java.lang.String, uuid: str | java.lang.String, connectMode: str | java.lang.String, name: str | java.lang.String, implementor: str | java.lang.String, /) -> None: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...

class AutomaticGainControl(AudioEffect):
    @staticmethod
    def create(audioSession: int | java.jint | java.lang.Integer, /) -> AutomaticGainControl | None: ...
    @staticmethod
    def isAvailable() -> bool: ...

class BassBoost(AudioEffect):
    PARAM_STRENGTH: typing.ClassVar[int] = ...
    PARAM_STRENGTH_SUPPORTED: typing.ClassVar[int] = ...
    def __init__(self, priority: int | java.jint | java.lang.Integer, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def getProperties(self) -> BassBoost.Settings: ...
    def getRoundedStrength(self) -> int: ...
    def getStrengthSupported(self) -> bool: ...
    def setParameterListener(self, listener: BassBoost.OnParameterChangeListener, /) -> None: ...
    def setProperties(self, settings: BassBoost.Settings, /) -> None: ...
    def setStrength(self, strength: int | java.jshort | java.lang.Short, /) -> None: ...

    class Settings(java.lang.Object):
        strength: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, settings: str | java.lang.String, /) -> None: ...
        def toString(self) -> str: ...

    class OnParameterChangeListener(java.lang.Object):
        def onParameterChange(self, arg1: BassBoost, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jshort | java.lang.Short, /) -> None: ...

class DynamicsProcessing(AudioEffect):
    VARIANT_FAVOR_FREQUENCY_RESOLUTION: typing.ClassVar[int] = ...
    VARIANT_FAVOR_TIME_RESOLUTION: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, priority: int | java.jint | java.lang.Integer, audioSession: int | java.jint | java.lang.Integer, cfg: DynamicsProcessing.Config, /) -> None: ...
    def getChannelByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Channel: ...
    def getChannelCount(self) -> int: ...
    def getConfig(self) -> DynamicsProcessing.Config: ...
    def getInputGainByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getLimiterByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Limiter: ...
    def getMbcBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.MbcBand: ...
    def getMbcByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Mbc: ...
    def getPostEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
    def getPostEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Eq: ...
    def getPreEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
    def getPreEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Eq: ...
    def setAllChannelsTo(self, channel: DynamicsProcessing.Channel, /) -> None: ...
    def setChannelTo(self, channelIndex: int | java.jint | java.lang.Integer, channel: DynamicsProcessing.Channel, /) -> None: ...
    def setInputGainAllChannelsTo(self, inputGain: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setInputGainbyChannel(self, channelIndex: int | java.jint | java.lang.Integer, inputGain: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setLimiterAllChannelsTo(self, limiter: DynamicsProcessing.Limiter, /) -> None: ...
    def setLimiterByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, limiter: DynamicsProcessing.Limiter, /) -> None: ...
    def setMbcAllChannelsTo(self, mbc: DynamicsProcessing.Mbc, /) -> None: ...
    def setMbcBandAllChannelsTo(self, band: int | java.jint | java.lang.Integer, mbcBand: DynamicsProcessing.MbcBand, /) -> None: ...
    def setMbcBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, mbcBand: DynamicsProcessing.MbcBand, /) -> None: ...
    def setMbcByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, mbc: DynamicsProcessing.Mbc, /) -> None: ...
    def setPostEqAllChannelsTo(self, postEq: DynamicsProcessing.Eq, /) -> None: ...
    def setPostEqBandAllChannelsTo(self, band: int | java.jint | java.lang.Integer, postEqBand: DynamicsProcessing.EqBand, /) -> None: ...
    def setPostEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, postEqBand: DynamicsProcessing.EqBand, /) -> None: ...
    def setPostEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, postEq: DynamicsProcessing.Eq, /) -> None: ...
    def setPreEqAllChannelsTo(self, preEq: DynamicsProcessing.Eq, /) -> None: ...
    def setPreEqBandAllChannelsTo(self, band: int | java.jint | java.lang.Integer, preEqBand: DynamicsProcessing.EqBand, /) -> None: ...
    def setPreEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, preEqBand: DynamicsProcessing.EqBand, /) -> None: ...
    def setPreEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, preEq: DynamicsProcessing.Eq, /) -> None: ...

    class Stage(java.lang.Object):
        def __init__(self, inUse: bool | java.jboolean | java.lang.Boolean, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def isEnabled(self) -> bool: ...
        def isInUse(self) -> bool: ...
        def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def toString(self) -> str: ...

    class MbcBand(DynamicsProcessing.BandBase):
        @typing.overload
        def __init__(self, cfg: DynamicsProcessing.MbcBand, /) -> None: ...
        @typing.overload
        def __init__(self, enabled: bool | java.jboolean | java.lang.Boolean, cutoffFrequency: float | java.jfloat | java.lang.Float, attackTime: float | java.jfloat | java.lang.Float, releaseTime: float | java.jfloat | java.lang.Float, ratio: float | java.jfloat | java.lang.Float, threshold: float | java.jfloat | java.lang.Float, kneeWidth: float | java.jfloat | java.lang.Float, noiseGateThreshold: float | java.jfloat | java.lang.Float, expanderRatio: float | java.jfloat | java.lang.Float, preGain: float | java.jfloat | java.lang.Float, postGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def getAttackTime(self) -> float: ...
        def getExpanderRatio(self) -> float: ...
        def getKneeWidth(self) -> float: ...
        def getNoiseGateThreshold(self) -> float: ...
        def getPostGain(self) -> float: ...
        def getPreGain(self) -> float: ...
        def getRatio(self) -> float: ...
        def getReleaseTime(self) -> float: ...
        def getThreshold(self) -> float: ...
        def setAttackTime(self, attackTime: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setExpanderRatio(self, expanderRatio: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setKneeWidth(self, kneeWidth: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setNoiseGateThreshold(self, noiseGateThreshold: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setPostGain(self, postGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setPreGain(self, preGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setRatio(self, ratio: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setReleaseTime(self, releaseTime: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setThreshold(self, threshold: float | java.jfloat | java.lang.Float, /) -> None: ...
        def toString(self) -> str: ...

    class Mbc(DynamicsProcessing.BandStage):
        @typing.overload
        def __init__(self, cfg: DynamicsProcessing.Mbc, /) -> None: ...
        @typing.overload
        def __init__(self, inUse: bool | java.jboolean | java.lang.Boolean, enabled: bool | java.jboolean | java.lang.Boolean, bandCount: int | java.jint | java.lang.Integer, /) -> None: ...
        def getBand(self, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.MbcBand: ...
        def setBand(self, band: int | java.jint | java.lang.Integer, bandCfg: DynamicsProcessing.MbcBand, /) -> None: ...
        def toString(self) -> str: ...

    class Limiter(DynamicsProcessing.Stage):
        @typing.overload
        def __init__(self, cfg: DynamicsProcessing.Limiter, /) -> None: ...
        @typing.overload
        def __init__(self, inUse: bool | java.jboolean | java.lang.Boolean, enabled: bool | java.jboolean | java.lang.Boolean, linkGroup: int | java.jint | java.lang.Integer, attackTime: float | java.jfloat | java.lang.Float, releaseTime: float | java.jfloat | java.lang.Float, ratio: float | java.jfloat | java.lang.Float, threshold: float | java.jfloat | java.lang.Float, postGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def getAttackTime(self) -> float: ...
        def getLinkGroup(self) -> int: ...
        def getPostGain(self) -> float: ...
        def getRatio(self) -> float: ...
        def getReleaseTime(self) -> float: ...
        def getThreshold(self) -> float: ...
        def setAttackTime(self, attackTime: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setLinkGroup(self, linkGroup: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPostGain(self, postGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setRatio(self, ratio: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setReleaseTime(self, releaseTime: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setThreshold(self, threshold: float | java.jfloat | java.lang.Float, /) -> None: ...
        def toString(self) -> str: ...

    class EqBand(DynamicsProcessing.BandBase):
        @typing.overload
        def __init__(self, cfg: DynamicsProcessing.EqBand, /) -> None: ...
        @typing.overload
        def __init__(self, enabled: bool | java.jboolean | java.lang.Boolean, cutoffFrequency: float | java.jfloat | java.lang.Float, gain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def getGain(self) -> float: ...
        def setGain(self, gain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def toString(self) -> str: ...

    class Eq(DynamicsProcessing.BandStage):
        @typing.overload
        def __init__(self, cfg: DynamicsProcessing.Eq, /) -> None: ...
        @typing.overload
        def __init__(self, inUse: bool | java.jboolean | java.lang.Boolean, enabled: bool | java.jboolean | java.lang.Boolean, bandCount: int | java.jint | java.lang.Integer, /) -> None: ...
        def getBand(self, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
        def setBand(self, band: int | java.jint | java.lang.Integer, bandCfg: DynamicsProcessing.EqBand, /) -> None: ...
        def toString(self) -> str: ...

    class Config(java.lang.Object):
        def getChannelByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Channel: ...
        def getInputGainByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> float: ...
        def getLimiterByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Limiter: ...
        def getMbcBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.MbcBand: ...
        def getMbcBandCount(self) -> int: ...
        def getMbcByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Mbc: ...
        def getPostEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
        def getPostEqBandCount(self) -> int: ...
        def getPostEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Eq: ...
        def getPreEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
        def getPreEqBandCount(self) -> int: ...
        def getPreEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.Eq: ...
        def getPreferredFrameDuration(self) -> float: ...
        def getVariant(self) -> int: ...
        def isLimiterInUse(self) -> bool: ...
        def isMbcInUse(self) -> bool: ...
        def isPostEqInUse(self) -> bool: ...
        def isPreEqInUse(self) -> bool: ...
        def setAllChannelsTo(self, channel: DynamicsProcessing.Channel, /) -> None: ...
        def setChannelTo(self, channelIndex: int | java.jint | java.lang.Integer, channel: DynamicsProcessing.Channel, /) -> None: ...
        def setInputGainAllChannelsTo(self, inputGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setInputGainByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, inputGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setLimiterAllChannelsTo(self, limiter: DynamicsProcessing.Limiter, /) -> None: ...
        def setLimiterByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, limiter: DynamicsProcessing.Limiter, /) -> None: ...
        def setMbcAllChannelsTo(self, mbc: DynamicsProcessing.Mbc, /) -> None: ...
        def setMbcBandAllChannelsTo(self, band: int | java.jint | java.lang.Integer, mbcBand: DynamicsProcessing.MbcBand, /) -> None: ...
        def setMbcBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, mbcBand: DynamicsProcessing.MbcBand, /) -> None: ...
        def setMbcByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, mbc: DynamicsProcessing.Mbc, /) -> None: ...
        def setPostEqAllChannelsTo(self, postEq: DynamicsProcessing.Eq, /) -> None: ...
        def setPostEqBandAllChannelsTo(self, band: int | java.jint | java.lang.Integer, postEqBand: DynamicsProcessing.EqBand, /) -> None: ...
        def setPostEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, postEqBand: DynamicsProcessing.EqBand, /) -> None: ...
        def setPostEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, postEq: DynamicsProcessing.Eq, /) -> None: ...
        def setPreEqAllChannelsTo(self, preEq: DynamicsProcessing.Eq, /) -> None: ...
        def setPreEqBandAllChannelsTo(self, band: int | java.jint | java.lang.Integer, preEqBand: DynamicsProcessing.EqBand, /) -> None: ...
        def setPreEqBandByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, band: int | java.jint | java.lang.Integer, preEqBand: DynamicsProcessing.EqBand, /) -> None: ...
        def setPreEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, preEq: DynamicsProcessing.Eq, /) -> None: ...
        def toString(self) -> str: ...

        class Builder(java.lang.Object):
            def __init__(self, variant: int | java.jint | java.lang.Integer, channelCount: int | java.jint | java.lang.Integer, preEqInUse: bool | java.jboolean | java.lang.Boolean, preEqBandCount: int | java.jint | java.lang.Integer, mbcInUse: bool | java.jboolean | java.lang.Boolean, mbcBandCount: int | java.jint | java.lang.Integer, postEqInUse: bool | java.jboolean | java.lang.Boolean, postEqBandCount: int | java.jint | java.lang.Integer, limiterInUse: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
            def build(self) -> DynamicsProcessing.Config: ...
            def setAllChannelsTo(self, channel: DynamicsProcessing.Channel, /) -> DynamicsProcessing.Config.Builder: ...
            def setChannelTo(self, channelIndex: int | java.jint | java.lang.Integer, channel: DynamicsProcessing.Channel, /) -> DynamicsProcessing.Config.Builder: ...
            def setInputGainAllChannelsTo(self, inputGain: float | java.jfloat | java.lang.Float, /) -> DynamicsProcessing.Config.Builder: ...
            def setInputGainByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, inputGain: float | java.jfloat | java.lang.Float, /) -> DynamicsProcessing.Config.Builder: ...
            def setLimiterAllChannelsTo(self, limiter: DynamicsProcessing.Limiter, /) -> DynamicsProcessing.Config.Builder: ...
            def setLimiterByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, limiter: DynamicsProcessing.Limiter, /) -> DynamicsProcessing.Config.Builder: ...
            def setMbcAllChannelsTo(self, mbc: DynamicsProcessing.Mbc, /) -> DynamicsProcessing.Config.Builder: ...
            def setMbcByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, mbc: DynamicsProcessing.Mbc, /) -> DynamicsProcessing.Config.Builder: ...
            def setPostEqAllChannelsTo(self, postEq: DynamicsProcessing.Eq, /) -> DynamicsProcessing.Config.Builder: ...
            def setPostEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, postEq: DynamicsProcessing.Eq, /) -> DynamicsProcessing.Config.Builder: ...
            def setPreEqAllChannelsTo(self, preEq: DynamicsProcessing.Eq, /) -> DynamicsProcessing.Config.Builder: ...
            def setPreEqByChannelIndex(self, channelIndex: int | java.jint | java.lang.Integer, preEq: DynamicsProcessing.Eq, /) -> DynamicsProcessing.Config.Builder: ...
            def setPreferredFrameDuration(self, frameDuration: float | java.jfloat | java.lang.Float, /) -> DynamicsProcessing.Config.Builder: ...

    class Channel(java.lang.Object):
        @typing.overload
        def __init__(self, cfg: DynamicsProcessing.Channel, /) -> None: ...
        @typing.overload
        def __init__(self, inputGain: float | java.jfloat | java.lang.Float, preEqInUse: bool | java.jboolean | java.lang.Boolean, preEqBandCount: int | java.jint | java.lang.Integer, mbcInUse: bool | java.jboolean | java.lang.Boolean, mbcBandCount: int | java.jint | java.lang.Integer, postEqInUse: bool | java.jboolean | java.lang.Boolean, postEqBandCount: int | java.jint | java.lang.Integer, limiterInUse: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def getInputGain(self) -> float: ...
        def getLimiter(self) -> DynamicsProcessing.Limiter: ...
        def getMbc(self) -> DynamicsProcessing.Mbc: ...
        def getMbcBand(self, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.MbcBand: ...
        def getPostEq(self) -> DynamicsProcessing.Eq: ...
        def getPostEqBand(self, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
        def getPreEq(self) -> DynamicsProcessing.Eq: ...
        def getPreEqBand(self, band: int | java.jint | java.lang.Integer, /) -> DynamicsProcessing.EqBand: ...
        def setInputGain(self, inputGain: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setLimiter(self, limiter: DynamicsProcessing.Limiter, /) -> None: ...
        def setMbc(self, mbc: DynamicsProcessing.Mbc, /) -> None: ...
        def setMbcBand(self, band: int | java.jint | java.lang.Integer, mbcBand: DynamicsProcessing.MbcBand, /) -> None: ...
        def setPostEq(self, postEq: DynamicsProcessing.Eq, /) -> None: ...
        def setPostEqBand(self, band: int | java.jint | java.lang.Integer, postEqBand: DynamicsProcessing.EqBand, /) -> None: ...
        def setPreEq(self, preEq: DynamicsProcessing.Eq, /) -> None: ...
        def setPreEqBand(self, band: int | java.jint | java.lang.Integer, preEqBand: DynamicsProcessing.EqBand, /) -> None: ...
        def toString(self) -> str: ...

    class BandStage(DynamicsProcessing.Stage):
        def __init__(self, inUse: bool | java.jboolean | java.lang.Boolean, enabled: bool | java.jboolean | java.lang.Boolean, bandCount: int | java.jint | java.lang.Integer, /) -> None: ...
        def getBandCount(self) -> int: ...
        def toString(self) -> str: ...

    class BandBase(java.lang.Object):
        def __init__(self, enabled: bool | java.jboolean | java.lang.Boolean, cutoffFrequency: float | java.jfloat | java.lang.Float, /) -> None: ...
        def getCutoffFrequency(self) -> float: ...
        def isEnabled(self) -> bool: ...
        def setCutoffFrequency(self, frequency: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def toString(self) -> str: ...

class EnvironmentalReverb(AudioEffect):
    PARAM_DECAY_HF_RATIO: typing.ClassVar[int] = ...
    PARAM_DECAY_TIME: typing.ClassVar[int] = ...
    PARAM_DENSITY: typing.ClassVar[int] = ...
    PARAM_DIFFUSION: typing.ClassVar[int] = ...
    PARAM_REFLECTIONS_DELAY: typing.ClassVar[int] = ...
    PARAM_REFLECTIONS_LEVEL: typing.ClassVar[int] = ...
    PARAM_REVERB_DELAY: typing.ClassVar[int] = ...
    PARAM_REVERB_LEVEL: typing.ClassVar[int] = ...
    PARAM_ROOM_HF_LEVEL: typing.ClassVar[int] = ...
    PARAM_ROOM_LEVEL: typing.ClassVar[int] = ...
    def __init__(self, priority: int | java.jint | java.lang.Integer, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDecayHFRatio(self) -> int: ...
    def getDecayTime(self) -> int: ...
    def getDensity(self) -> int: ...
    def getDiffusion(self) -> int: ...
    def getProperties(self) -> EnvironmentalReverb.Settings: ...
    def getReflectionsDelay(self) -> int: ...
    def getReflectionsLevel(self) -> int: ...
    def getReverbDelay(self) -> int: ...
    def getReverbLevel(self) -> int: ...
    def getRoomHFLevel(self) -> int: ...
    def getRoomLevel(self) -> int: ...
    def setDecayHFRatio(self, decayHFRatio: int | java.jshort | java.lang.Short, /) -> None: ...
    def setDecayTime(self, decayTime: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDensity(self, density: int | java.jshort | java.lang.Short, /) -> None: ...
    def setDiffusion(self, diffusion: int | java.jshort | java.lang.Short, /) -> None: ...
    def setParameterListener(self, listener: EnvironmentalReverb.OnParameterChangeListener, /) -> None: ...
    def setProperties(self, settings: EnvironmentalReverb.Settings, /) -> None: ...
    def setReflectionsDelay(self, reflectionsDelay: int | java.jint | java.lang.Integer, /) -> None: ...
    def setReflectionsLevel(self, reflectionsLevel: int | java.jshort | java.lang.Short, /) -> None: ...
    def setReverbDelay(self, reverbDelay: int | java.jint | java.lang.Integer, /) -> None: ...
    def setReverbLevel(self, reverbLevel: int | java.jshort | java.lang.Short, /) -> None: ...
    def setRoomHFLevel(self, roomHF: int | java.jshort | java.lang.Short, /) -> None: ...
    def setRoomLevel(self, room: int | java.jshort | java.lang.Short, /) -> None: ...

    class Settings(java.lang.Object):
        decayHFRatio: int = ...
        decayTime: int = ...
        density: int = ...
        diffusion: int = ...
        reflectionsDelay: int = ...
        reflectionsLevel: int = ...
        reverbDelay: int = ...
        reverbLevel: int = ...
        roomHFLevel: int = ...
        roomLevel: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, settings: str | java.lang.String, /) -> None: ...
        def toString(self) -> str: ...

    class OnParameterChangeListener(java.lang.Object):
        def onParameterChange(self, arg1: EnvironmentalReverb, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class Equalizer(AudioEffect):
    PARAM_BAND_FREQ_RANGE: typing.ClassVar[int] = ...
    PARAM_BAND_LEVEL: typing.ClassVar[int] = ...
    PARAM_CENTER_FREQ: typing.ClassVar[int] = ...
    PARAM_CURRENT_PRESET: typing.ClassVar[int] = ...
    PARAM_GET_BAND: typing.ClassVar[int] = ...
    PARAM_GET_NUM_OF_PRESETS: typing.ClassVar[int] = ...
    PARAM_GET_PRESET_NAME: typing.ClassVar[int] = ...
    PARAM_LEVEL_RANGE: typing.ClassVar[int] = ...
    PARAM_NUM_BANDS: typing.ClassVar[int] = ...
    PARAM_STRING_SIZE_MAX: typing.ClassVar[int] = ...
    def __init__(self, priority: int | java.jint | java.lang.Integer, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def getBand(self, frequency: int | java.jint | java.lang.Integer, /) -> int: ...
    def getBandFreqRange(self, band: int | java.jshort | java.lang.Short, /) -> java.chaquopy.JavaArrayJInt: ...
    def getBandLevel(self, band: int | java.jshort | java.lang.Short, /) -> int: ...
    def getBandLevelRange(self) -> java.chaquopy.JavaArrayJShort: ...
    def getCenterFreq(self, band: int | java.jshort | java.lang.Short, /) -> int: ...
    def getCurrentPreset(self) -> int: ...
    def getNumberOfBands(self) -> int: ...
    def getNumberOfPresets(self) -> int: ...
    def getPresetName(self, preset: int | java.jshort | java.lang.Short, /) -> str: ...
    def getProperties(self) -> Equalizer.Settings: ...
    def setBandLevel(self, band: int | java.jshort | java.lang.Short, level: int | java.jshort | java.lang.Short, /) -> None: ...
    def setParameterListener(self, listener: Equalizer.OnParameterChangeListener, /) -> None: ...
    def setProperties(self, settings: Equalizer.Settings, /) -> None: ...
    def usePreset(self, preset: int | java.jshort | java.lang.Short, /) -> None: ...

    class Settings(java.lang.Object):
        bandLevels: java.chaquopy.JavaArrayJShort = ...
        curPreset: int = ...
        numBands: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, settings: str | java.lang.String, /) -> None: ...
        def toString(self) -> str: ...

    class OnParameterChangeListener(java.lang.Object):
        def onParameterChange(self, arg1: Equalizer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...

class HapticGenerator(AudioEffect, java.lang.AutoCloseable):
    def close(self) -> None: ...
    @staticmethod
    def create(audioSession: int | java.jint | java.lang.Integer, /) -> HapticGenerator | None: ...
    @staticmethod
    def isAvailable() -> bool: ...
    def release(self) -> None: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> int: ...

class LoudnessEnhancer(AudioEffect):
    PARAM_TARGET_GAIN_MB: typing.ClassVar[int] = ...
    def __init__(self, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def getTargetGain(self) -> float: ...
    def setTargetGain(self, gainmB: int | java.jint | java.lang.Integer, /) -> None: ...

class NoiseSuppressor(AudioEffect):
    @staticmethod
    def create(audioSession: int | java.jint | java.lang.Integer, /) -> NoiseSuppressor | None: ...
    @staticmethod
    def isAvailable() -> bool: ...

class PresetReverb(AudioEffect):
    PARAM_PRESET: typing.ClassVar[int] = ...
    PRESET_LARGEHALL: typing.ClassVar[int] = ...
    PRESET_LARGEROOM: typing.ClassVar[int] = ...
    PRESET_MEDIUMHALL: typing.ClassVar[int] = ...
    PRESET_MEDIUMROOM: typing.ClassVar[int] = ...
    PRESET_NONE: typing.ClassVar[int] = ...
    PRESET_PLATE: typing.ClassVar[int] = ...
    PRESET_SMALLROOM: typing.ClassVar[int] = ...
    def __init__(self, priority: int | java.jint | java.lang.Integer, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def getPreset(self) -> int: ...
    def getProperties(self) -> PresetReverb.Settings: ...
    def setParameterListener(self, listener: PresetReverb.OnParameterChangeListener, /) -> None: ...
    def setPreset(self, preset: int | java.jshort | java.lang.Short, /) -> None: ...
    def setProperties(self, settings: PresetReverb.Settings, /) -> None: ...

    class Settings(java.lang.Object):
        preset: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, settings: str | java.lang.String, /) -> None: ...
        def toString(self) -> str: ...

    class OnParameterChangeListener(java.lang.Object):
        def onParameterChange(self, arg1: PresetReverb, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jshort | java.lang.Short, /) -> None: ...

class Virtualizer(AudioEffect):
    PARAM_STRENGTH: typing.ClassVar[int] = ...
    PARAM_STRENGTH_SUPPORTED: typing.ClassVar[int] = ...
    VIRTUALIZATION_MODE_AUTO: typing.ClassVar[int] = ...
    VIRTUALIZATION_MODE_BINAURAL: typing.ClassVar[int] = ...
    VIRTUALIZATION_MODE_OFF: typing.ClassVar[int] = ...
    VIRTUALIZATION_MODE_TRANSAURAL: typing.ClassVar[int] = ...
    def __init__(self, priority: int | java.jint | java.lang.Integer, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def canVirtualize(self, inputChannelMask: int | java.jint | java.lang.Integer, virtualizationMode: int | java.jint | java.lang.Integer, /) -> bool: ...
    def forceVirtualizationMode(self, virtualizationMode: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getProperties(self) -> Virtualizer.Settings: ...
    def getRoundedStrength(self) -> int: ...
    def getSpeakerAngles(self, inputChannelMask: int | java.jint | java.lang.Integer, virtualizationMode: int | java.jint | java.lang.Integer, angles: java.chaquopy.JavaArrayJInt, /) -> bool: ...
    def getStrengthSupported(self) -> bool: ...
    def getVirtualizationMode(self) -> int: ...
    def setParameterListener(self, listener: Virtualizer.OnParameterChangeListener, /) -> None: ...
    def setProperties(self, settings: Virtualizer.Settings, /) -> None: ...
    def setStrength(self, strength: int | java.jshort | java.lang.Short, /) -> None: ...

    class Settings(java.lang.Object):
        strength: int = ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, settings: str | java.lang.String, /) -> None: ...
        def toString(self) -> str: ...

    class OnParameterChangeListener(java.lang.Object):
        def onParameterChange(self, arg1: Virtualizer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jshort | java.lang.Short, /) -> None: ...

class Visualizer(java.lang.Object):
    ALREADY_EXISTS: typing.ClassVar[int] = ...
    ERROR: typing.ClassVar[int] = ...
    ERROR_BAD_VALUE: typing.ClassVar[int] = ...
    ERROR_DEAD_OBJECT: typing.ClassVar[int] = ...
    ERROR_INVALID_OPERATION: typing.ClassVar[int] = ...
    ERROR_NO_INIT: typing.ClassVar[int] = ...
    ERROR_NO_MEMORY: typing.ClassVar[int] = ...
    MEASUREMENT_MODE_NONE: typing.ClassVar[int] = ...
    MEASUREMENT_MODE_PEAK_RMS: typing.ClassVar[int] = ...
    SCALING_MODE_AS_PLAYED: typing.ClassVar[int] = ...
    SCALING_MODE_NORMALIZED: typing.ClassVar[int] = ...
    STATE_ENABLED: typing.ClassVar[int] = ...
    STATE_INITIALIZED: typing.ClassVar[int] = ...
    STATE_UNINITIALIZED: typing.ClassVar[int] = ...
    SUCCESS: typing.ClassVar[int] = ...
    def __init__(self, audioSession: int | java.jint | java.lang.Integer, /) -> None: ...
    def finalize(self) -> None: ...
    def getCaptureSize(self) -> int: ...
    @staticmethod
    def getCaptureSizeRange() -> java.chaquopy.JavaArrayJInt: ...
    def getEnabled(self) -> bool: ...
    def getFft(self, fft: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @staticmethod
    def getMaxCaptureRate() -> int: ...
    def getMeasurementMode(self) -> int: ...
    def getMeasurementPeakRms(self, measurement: Visualizer.MeasurementPeakRms, /) -> int: ...
    def getSamplingRate(self) -> int: ...
    def getScalingMode(self) -> int: ...
    def getWaveForm(self, waveform: java.chaquopy.JavaArrayJByte, /) -> int: ...
    def release(self) -> None: ...
    def setCaptureSize(self, size: int | java.jint | java.lang.Integer, /) -> int: ...
    def setDataCaptureListener(self, listener: Visualizer.OnDataCaptureListener, rate: int | java.jint | java.lang.Integer, waveform: bool | java.jboolean | java.lang.Boolean, fft: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def setEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def setMeasurementMode(self, mode: int | java.jint | java.lang.Integer, /) -> int: ...
    def setScalingMode(self, mode: int | java.jint | java.lang.Integer, /) -> int: ...

    class OnDataCaptureListener(java.lang.Object):
        def onFftDataCapture(self, arg1: Visualizer, arg2: java.chaquopy.JavaArrayJByte, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
        def onWaveFormDataCapture(self, arg1: Visualizer, arg2: java.chaquopy.JavaArrayJByte, arg3: int | java.jint | java.lang.Integer, /) -> None: ...

    class MeasurementPeakRms(java.lang.Object):
        mPeak: int = ...
        mRms: int = ...
        def __init__(self) -> None: ...



import java.chaquopy
import java.lang
import java.lang.annotation

class FlaggedApi(java.lang.annotation.Annotation):
    def value(self) -> str: ...

class NonNull(java.lang.annotation.Annotation): ...

class Nullable(java.lang.annotation.Annotation): ...

class SuppressLint(java.lang.annotation.Annotation):
    def value(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class TargetApi(java.lang.annotation.Annotation):
    def value(self) -> int: ...
